@@ -1,8 +1,8 @@
 # Added '...' to some base functions. These will later be
 # turned into default functions by setMethodS3().
 
-flush <- appendVarArgs(flush);
 write <- appendVarArgs(write);
+
 if (exists("restart", mode="function")) {
   restart <- NULL; rm(list="restart"); # To please R CMD check on R (>= 2.15.0)
   restart <- appendVarArgs(restart);
@@ -14,11 +14,6 @@ setMethodS3("stop", "default", function(...) {
   base::stop(...);
 })
 
-parse <- function(...) UseMethod("parse");
-parse.default <- function(...) {
-  base::parse(...);
-}
-
 ############################################################################
 # HISTORY:
 # 2005-08-01
