@@ -52,15 +52,15 @@
 #   Using @see "Rscript" and \code{rfile()}, it is possible to process
 #   an RSP file from the command line.  For example,
 #
-#   \code{Rscript -e "R.rsp::rfile(file='RSP-refcard.tex.rsp', path=system.file('doc', package='R.rsp'))"}
+#   \code{Rscript -e "R.rsp::rfile(file='RSP_refcard.tex.rsp', path=system.file('doc', package='R.rsp'))"}
 #
-#   parses and evaluates \file{RSP-refcard.tex.rsp} and output \file{RSP-refcard.pdf} in the current directory.
+#   parses and evaluates \file{RSP_refcard.tex.rsp} and output \file{RSP_refcard.pdf} in the current directory.
 # }
 #
 # \examples{
 # @include "../incl/rfile.Rex"
 #
-# \donttest{
+# \dontrun{
 # # Compile and display the main vignette (requires LaTeX)
 # if (isCapableOf(R.rsp, "latex")) {
 #   path <- system.file("doc", package="R.rsp")
@@ -93,7 +93,7 @@ setMethodS3("rfile", "default", function(file, path=NULL, output=NULL, workdir=N
     }
     if (!isUrl(file)) {
       withoutGString({
-        file <- Arguments$getReadablePathname(file, absolute=TRUE);
+        file <- Arguments$getReadablePathname(file, absolutePath=TRUE);
       })
     }
   }
@@ -539,6 +539,10 @@ setMethodS3("rfile", "expression", function(object, ..., envir=parent.frame(), v
 
 ############################################################################
 # HISTORY:
+# 2015-02-14
+# o CRAN: Used to have \donttest{} in example(rfile), which was there to
+#   avoid the test running longer than 5 seconds.  This was disapproved
+#   in resubmission.  Now using \dontrun{} instead.
 # 2014-05-30
 # o Now metadata 'source' is set by rfile(), iff possible.  It gives the
 #   absolute path to the input file, or the URL, of the source RSP file.
